@@ -8,6 +8,7 @@ rm(list = ls())
 library(data.table)
 #install.packages("foreign")
 library(foreign)
+library(pdynmc)
 
 
 
@@ -54,8 +55,8 @@ m2 <- pdynmc(dat = dat, varname.i = "i", varname.t = "t",
              include.x = TRUE, varname.reg.end = "lrxtot", lagTerms.reg.end = 0, maxLags.reg.end = 5,
              varname.reg.ex	= "lrhearn", lagTerms.reg.ex = 0, maxLags.reg.ex = 5,
              include.x.instr = TRUE, varname.reg.instr = "lrhearn", include.x.toInstr = FALSE,
-             fur.con = FALSE, fur.con.diff = FALSE, fur.con.lev = FALSE,
-             varname.reg.fur = c("nch","nad","hage","hage2"), lagTerms.reg.fur = c(0,0,0,0),
+             fur.con = FALSE, fur.con.diff = NULL, fur.con.lev = NULL,
+             varname.reg.fur = NULL, lagTerms.reg.fur = NULL,
              include.dum = TRUE, dum.diff = TRUE, dum.lev = FALSE, varname.dum = c("week", "yearquarter"),
              w.mat = "iid.err", std.err = "corrected", estimation = "onestep",
              opt.meth = "none")
@@ -67,8 +68,8 @@ m3 <- pdynmc(dat = dat, varname.i = "i", varname.t = "t",
              include.x = TRUE, varname.reg.end = "lrxtot", lagTerms.reg.end = 0, maxLags.reg.end = 5,
              varname.reg.ex	= "lrhearn", lagTerms.reg.ex = 0, maxLags.reg.ex = 5,
              include.x.instr = TRUE, varname.reg.instr = "lrhearn", include.x.toInstr = FALSE,
-             fur.con = FALSE, fur.con.diff = FALSE, fur.con.lev = FALSE,
-             varname.reg.fur = c("nch","nad","hage","hage2"), lagTerms.reg.fur = c(0,0,0,0),
+             fur.con = FALSE, fur.con.diff = NULL, fur.con.lev = NULL,
+             varname.reg.fur = NULL, lagTerms.reg.fur = NULL,
              include.dum = TRUE, dum.diff = FALSE, dum.lev = TRUE, varname.dum = c("week", "yearquarter"),
              w.mat = "iid.err", std.err = "corrected", estimation = "onestep",
              opt.meth = "none")
@@ -80,9 +81,9 @@ m4 <- pdynmc(dat = dat, varname.i = "i", varname.t = "t",
              include.x = TRUE, varname.reg.end = "lrxtot", lagTerms.reg.end = 0, maxLags.reg.end = 5,
              varname.reg.ex	= "lrhearn", lagTerms.reg.ex = 0, maxLags.reg.ex = 5,
              include.x.instr = TRUE, varname.reg.instr = "lrhearn", include.x.toInstr = FALSE,
-             fur.con = FALSE, fur.con.diff = FALSE, fur.con.lev = FALSE,
-             varname.reg.fur = c("nch","nad","hage","hage2"), lagTerms.reg.fur = c(0,0,0,0),
-             include.dum = FALSE, dum.diff = FALSE, dum.lev = FALSE, varname.dum = c("week", "yearquarter"),
+             fur.con = FALSE, fur.con.diff = NULL, fur.con.lev = NULL,
+             varname.reg.fur = NULL, lagTerms.reg.fur = NULL,
+             include.dum = FALSE, dum.diff = NULL, dum.lev = NULL, varname.dum = NULL,
              w.mat = "iid.err", std.err = "corrected", estimation = "onestep",
              opt.meth = "none")
 summary(m4)
@@ -134,7 +135,7 @@ m8 <- pdynmc(dat = dat, varname.i = "i", varname.t = "t",
              include.x.instr = TRUE, varname.reg.instr = "lrhearn", include.x.toInstr = FALSE,
              fur.con = TRUE, fur.con.diff = TRUE, fur.con.lev = TRUE,
              varname.reg.fur = c("nch","nad","hage","hage2"), lagTerms.reg.fur = c(0,0,0,0),
-             include.dum = FALSE, dum.diff = FALSE, dum.lev = FALSE, varname.dum = c("week", "yearquarter"),
+             include.dum = FALSE, dum.diff = NULL, dum.lev = NULL, varname.dum = NULL,
              w.mat = "iid.err", std.err = "corrected", estimation = "onestep",
              opt.meth = "none")
 summary(m8)
@@ -186,7 +187,7 @@ m12 <- pdynmc(dat = dat, varname.i = "i", varname.t = "t",
               include.x.instr = TRUE, varname.reg.instr = "lrhearn", include.x.toInstr = FALSE,
               fur.con = TRUE, fur.con.diff = TRUE, fur.con.lev = FALSE,
               varname.reg.fur = c("nch","nad","hage","hage2"), lagTerms.reg.fur = c(0,0,0,0),
-              include.dum = FALSE, dum.diff = FALSE, dum.lev = FALSE, varname.dum = c("week", "yearquarter"),
+              include.dum = FALSE, dum.diff = NULL, dum.lev = NULL, varname.dum = NULL,
               w.mat = "iid.err", std.err = "corrected", estimation = "onestep",
               opt.meth = "none")
 summary(m12)
@@ -242,3 +243,13 @@ m16 <- pdynmc(dat = dat, varname.i = "i", varname.t = "t",
               w.mat = "iid.err", std.err = "corrected", estimation = "onestep",
               opt.meth = "none")
 summary(m16)
+
+
+
+
+
+
+ls()[grepl(ls(), pattern = "m")]
+length(ls()[grepl(ls(), pattern = "m")])		# 16 configurations are estimated
+
+
